==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueStructValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueStructValueFluent<A extends ValueStructValueFluent<A>> extends BaseFluent<A>{
  public ValueStructValueFluent() {
  }
  public ValueStructValueFluent(ValueStructValue instance) {
    instance = (instance != null ? instance : new ValueStructValue());

    if (instance != null) {
      this.withStructValue(instance.getStructValue());
      this.withStructValue(instance.getStructValue());
    }
  }
  private Map<String,Object> structValue;
  public A addToStructValue(String key,Object value) {
    if(this.structValue == null && key != null && value != null) { this.structValue = new LinkedHashMap(); }
    if(key != null && value != null) {this.structValue.put(key, value);} return (A)this;
  }
  public A addToStructValue(Map<String,Object> map) {
    if(this.structValue == null && map != null) { this.structValue = new LinkedHashMap(); }
    if(map != null) { this.structValue.putAll(map);} return (A)this;
  }
  public A removeFromStructValue(String key) {
    if(this.structValue == null) { return (A) this; }
    if(key != null && this.structValue != null) {this.structValue.remove(key);} return (A)this;
  }
  public A removeFromStructValue(Map<String,Object> map) {
    if(this.structValue == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.structValue != null){this.structValue.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getStructValue() {
    return this.structValue;
  }
  public <K,V>A withStructValue(Map<String,Object> structValue) {
    if (structValue == null) { this.structValue =  null;} else {this.structValue = new LinkedHashMap(structValue);} return (A) this;
  }
  public boolean hasStructValue() {
    return this.structValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueStructValueFluent that = (ValueStructValueFluent) o;
    if (!java.util.Objects.equals(structValue, that.structValue)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(structValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (structValue != null && !structValue.isEmpty()) { sb.append("structValue:"); sb.append(structValue); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueStructValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValueStructValueFluent<A extends ValueStructValueFluent<A>> extends BaseFluent<A>{
  public ValueStructValueFluent() {
  }
  
  public ValueStructValueFluent(ValueStructValue instance) {
    this.copyInstance(instance);
  }
  private Map<String,Object> structValue;
  
  protected void copyInstance(ValueStructValue instance) {
    instance = (instance != null ? instance : new ValueStructValue());
  
    if (instance != null) {
        this.withStructValue(instance.getStructValue());
        this.withStructValue(instance.getStructValue());
      }
  }
  
  public A addToStructValue(String key,Object value) {
    if(this.structValue == null && key != null && value != null) { this.structValue = new LinkedHashMap(); }
    if(key != null && value != null) {this.structValue.put(key, value);} return (A)this;
  }
  
  public A addToStructValue(Map<String,Object> map) {
    if(this.structValue == null && map != null) { this.structValue = new LinkedHashMap(); }
    if(map != null) { this.structValue.putAll(map);} return (A)this;
  }
  
  public A removeFromStructValue(String key) {
    if(this.structValue == null) { return (A) this; }
    if(key != null && this.structValue != null) {this.structValue.remove(key);} return (A)this;
  }
  
  public A removeFromStructValue(Map<String,Object> map) {
    if(this.structValue == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.structValue != null){this.structValue.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getStructValue() {
    return this.structValue;
  }
  
  public <K,V>A withStructValue(Map<String,Object> structValue) {
    if (structValue == null) { this.structValue =  null;} else {this.structValue = new LinkedHashMap(structValue);} return (A) this;
  }
  
  public boolean hasStructValue() {
    return this.structValue != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueStructValueFluent that = (ValueStructValueFluent) o;
    if (!java.util.Objects.equals(structValue, that.structValue)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(structValue,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (structValue != null && !structValue.isEmpty()) { sb.append("structValue:"); sb.append(structValue); }
    sb.append("}");
    return sb.toString();
  }
  

}
